require("chartdirector")

class CrosshairController < ApplicationController
    include ChartDirector::InteractiveChartSupport

    def index()
        @ctrl_file = File.expand_path(__FILE__)

        # The XY data of the first data series
        dataX = [50, 55, 37, 24, 42, 49, 63, 72, 83, 59]
        dataY = [3.6, 2.8, 2.5, 2.3, 3.8, 3.0, 3.8, 5.0, 6.0, 3.3]

        # Create a XYChart object of size 520 x 490 pixels
        c = ChartDirector::XYChart.new(520, 490)

        # Set the plotarea at (60, 40) and of size 450 x 400 pixels, with white background
        # and a light grey border (0xc0c0c0). Turn on both horizontal and vertical grid
        # lines with light grey color (0xc0c0c0)
        c.setPlotArea(60, 40, 450, 400, 0xffffff, -1, 0xc0c0c0, 0xc0c0c0, -1)

        # Add a title to the chart using 18 point Times Bold Itatic font.
        c.addTitle("      Chemical X Thermal Conductivity", "timesbi.ttf", 18)

        # Add titles to the axes using 12 pts Arial Bold Italic font
        c.yAxis().setTitle("Thermal Conductivity (W/K)", "arialbi.ttf", 12)
        c.xAxis().setTitle("Concentration (g/liter)", "arialbi.ttf", 12)

        # Set the axes line width to 3 pixels
        c.yAxis().setWidth(3)
        c.xAxis().setWidth(3)

        # Add a scatter layer using (dataX, dataY)
        scatterLayer = c.addScatterLayer(dataX, dataY, "",
            ChartDirector::GlassSphereShape, 13, 0xcc0000)

        # Show custom Javascript tooltip for the scatter layer
        scatterLayer.setHTMLImageMap("", "",
            "onmouseover='showDataPointToolTip({x}, {value})' onmouseout='hideToolTip()'")

        # Add a trend line layer for (dataX, dataY)
        trendLayer = c.addTrendLayer2(dataX, dataY, 0xcc0000)

        # Set the line width to 3 pixels
        trendLayer.setLineWidth(3)

        # Add a 95% confidence band for the line
        trendLayer.addConfidenceBand(0.95, 0x806666ff)

        # Add a 95% confidence band (prediction band) for the points
        trendLayer.addPredictionBand(0.95, 0x8066ff66)

        # Show custom Javascript tooltip for the trend layer
        trendLayer.setHTMLImageMap("", "",
            "onmouseover='showTrendLineToolTip({slope}, {intercept})' " \
            "onmouseout='hideToolTip()'")

        # Add a legend box at (60, 35) (top of the chart) with horizontal layout. Use 10
        # pts Arial Bold Italic font. Set the background and border color to Transparent
        # and use line style legend icons.
        legendBox = c.addLegend(60, 35, false, "arialbi.ttf", 9)
        legendBox.setBackground(ChartDirector::Transparent)
        legendBox.setLineStyleKey(true)

        # Add entries to the legend box
        legendBox.addKey("95% Line Confidence", 0x806666ff)
        legendBox.addKey("95% Point Confidence", 0x8066ff66)
        legendBox.addKey(sprintf("Trend Line: y = %.4f x + %.4f", trendLayer.getSlope(),
            trendLayer.getIntercept()), 0xcc0000, 3)

        # Create the WebChartViewer object
        @viewer = ChartDirector::WebChartViewer.new(request, "chart1")

        # Create the image and save it in a session variable
        session[@viewer.getId()] = c.makeChart2(ChartDirector::PNG)

        # Include tool tip for the chart
        imageMap = c.getHTMLImageMap("")

        # Set the chart URL and image map to the viewer
        @viewer.setImageUrl(url_for(:action => "get_session_data", :id => @viewer.getId(),
            :nocache => rand))
        @viewer.setImageMap(imageMap)

        # Output Javascript chart model to the browser to support tracking cursor
        @viewer.setChartModel(c.getJsChartModel())
    end

end
